@@ -7,7 +7,7 @@ from esprima import parseScript, nodes
 
 from werkzeug._compat import iteritems, iterkeys, to_unicode, to_bytes, text_type, string_types
 
-from jam.common import consts
+from jam.common import consts, get_ext_list
 from jam.dataset import FIELD_NAME, FIELD_CAPTION, FIELD_LOOKUP_VALUES
 
 from jam.common import consts, error_message, file_read, file_write
@@ -26,10 +26,9 @@ LOOKUP_LISTS = {
         'f_alignment': consts.ALIGNMENT,
         'f_type': consts.FILTER_STRING,
         'label_size': ['xSmall', 'Small', 'Medium', 'Large', 'xLarge'],
-        'group_type': consts.GROUP_TYPES,
-
+        'group_type': consts.GROUP_TYPES
     }
-    
+
 def get_value_list(str_list):
     result = []
     for i, s in enumerate(str_list):
@@ -66,17 +65,17 @@ def restore_caption_keys(task):
     def restore_keys(item):
         if hasattr(item, 'field_defs'):
             for field_def in item.field_defs:
-                field_def[FIELD_CAPTION] = item.__caption_keys[field_def[FIELD_NAME]] 
+                field_def[FIELD_CAPTION] = item.__caption_keys[field_def[FIELD_NAME]]
 
     task.all(restore_keys)
 
 def change_language(task):
-    
+
     def change_fields_lang(item):
         if hasattr(item, 'field_defs'):
             for field_def in item.field_defs:
                 field_def[FIELD_CAPTION] = item.task.language(field_def[FIELD_CAPTION])
-    
+
     restore_caption_keys(task)
     consts.read_language()
     task.all(change_fields_lang)
@@ -718,11 +717,11 @@ def server_save_edit(task, item_id, text, is_server):
 def set_server_modified(task):
     if task.item_name == 'admin':
         task.app.server_modified = True
-    
+
 def set_client_modified(task):
     if task.item_name == 'admin':
         task.app.client_modified = True
-    
+
 def server_file_info(task, file_name):
     result = {}
     file_path = file_name
@@ -801,6 +800,13 @@ def server_can_delete_lookup_list(task, list_id):
         mess = task.language('lookup_list_is_used_in') % names
         return mess
 
+def server_valid_field_accept_value(task, accept):
+    try:
+        get_ext_list(accept)
+        return True
+    except:
+        return False
+
 def server_valid_item_name(task, item_id, parent_id, name, type_id):
     result = ''
     items = task.sys_items.copy(handlers=False, details=False)
@@ -1163,7 +1169,7 @@ def upload_file(task, path, file_name, f):
             os.makedirs(dir_path)
         f.save(os.path.join(dir_path, file_name))
         return path, file_name
-    
+
 
 ###############################################################################
 #                                  sys_items                                  #
@@ -1499,7 +1505,7 @@ def server_store_interface(item, id_value, info):
     item.open(fields=['id', 'f_info'])
     item._view_list = info['view_list']
     item._edit_list = info['edit_list']
-    item._order_list = info['order_list'] 
+    item._order_list = info['order_list']
     item._reports_list = info['reports_list']
     item.store_interface()
     set_server_modified(item.task)
@@ -2057,6 +2063,7 @@ def register_events(task):
     task.register(server_get_task_info)
     task.register(server_can_delete_lookup_list)
     task.register(server_valid_item_name)
+    task.register(server_valid_field_accept_value)
     task.register(server_get_primary_key_type)
     task.register(server_set_literal_case)
     task.register(server_lang_modified)
